@@ -97,10 +97,7 @@ class One(ConversionMixin):
             if 'date_created' not in meta['raw'][table]:
                 _logger.warning(f"{cache_file} does not appear to be a valid table. Skipping")
                 continue
-            created = datetime.fromisoformat(meta['raw'][table]['date_created'])
-            meta['created_time'] = min([meta['created_time'] or datetime.max, created])
             meta['loaded_time'] = datetime.now()
-            meta['expired'] |= datetime.now() - created > self.cache_expiry
 
             # Convert to str ids
             cache = util.cache_int2str(cache)
@@ -122,8 +119,14 @@ class One(ConversionMixin):
         if len(self._cache) == 1:
             # No tables present
             meta['expired'] = True
+            meta['raw'] = {}
             self._cache.update({'datasets': pd.DataFrame(), 'sessions': pd.DataFrame()})
         self._cache['_meta'] = meta
+        created = [datetime.fromisoformat(x['date_created'])
+                   for x in meta['raw'].values() if 'date_created' in x]
+        if created:
+            meta['created_time'] = min(created)
+            meta['expired'] |= datetime.now() - meta['created_time'] > self.cache_expiry
         return self._cache['_meta']['loaded_time']
 
     def save_cache(self, save_dir=None, force=False):
@@ -508,7 +511,7 @@ class One(ConversionMixin):
                 new_size = file.stat().st_size
                 size_mismatch = rec['file_size'] and new_size != rec['file_size']
                 if hash_mismatch or size_mismatch:
-                    full_relative_path = rec.session_path + rec.rel_path
+                    full_relative_path = PurePosixPath(rec.session_path, rec.rel_path)
                     _logger.warning(f'local md5 or size mismatch on dataset: {full_relative_path}')
                     # Mismatch: add this index to list of datasets that need downloading
                     indices_to_download.append(i)
@@ -1425,10 +1428,12 @@ class OneAlyx(One):
             files = self.alyx.download_cache_tables(cache_info.get('location'))
             assert any(files)
             super(OneAlyx, self)._load_cache(self.cache_dir)  # Reload cache after download
-        except (requests.exceptions.HTTPError, wc.HTTPError):
+        except (requests.exceptions.HTTPError, wc.HTTPError) as ex:
+            _logger.debug(ex)
             _logger.error('Failed to load the remote cache file')
             self.mode = 'remote'
-        except (ConnectionError, requests.exceptions.ConnectionError):
+        except (ConnectionError, requests.exceptions.ConnectionError) as ex:
+            _logger.debug(ex)
             _logger.error('Failed to connect to Alyx')
             self.mode = 'local'
 
@@ -1662,29 +1667,11 @@ class OneAlyx(One):
 
     def _download_aws(self, dsets, update_exists=True, **kwargs) -> List[Path]:
         # Download datasets from AWS
-        from tqdm import tqdm
-        import boto3
-        from botocore.exceptions import NoCredentialsError, PartialCredentialsError, ClientError
-
-        def _callback_hook(t):
-            # https://gist.github.com/wy193777/e7607d12fad13459e8992d4f69b53586
-            # For example that uses actual file size:
-            # boto3.amazonaws.com/v1/documentation/api/latest/_modules/boto3/s3/transfer.html
-            def inner(bytes_amount):
-                t.update(bytes_amount)
-            return inner
-
+        import one.remote.aws as aws
+        s3, bucket_name = aws.get_s3_from_alyx(self)
         if self._index_type() is int:
             raise NotImplementedError('AWS download only supported for str index cache')
         assert self.mode != 'local'
-        repo_json = self.alyx.rest('data-repository', 'read', id='aws_cortexlab')['json']
-        bucket_name = repo_json['bucket_name']
-        session_keys = {
-            'aws_access_key_id': repo_json.get('Access key ID', None),
-            'aws_secret_access_key': repo_json.get('Secret access key', None)
-        }
-        session = boto3.Session(**session_keys)
-        s3 = session.resource('s3')
         # Get all dataset URLs
         dsets = list(dsets)  # Ensure not generator
         uuids = [util.ensure_list(x.name)[-1] for x in dsets]
@@ -1706,19 +1693,8 @@ class OneAlyx(One):
             local_path = alfio.remove_uuid_file(
                 self.cache_dir.joinpath(dset['session_path'], dset['rel_path']), dry=True)
             local_path.parent.mkdir(exist_ok=True, parents=True)
-            out_files.append(local_path)
-            try:
-                file_object = s3.Object(bucket_name, source_path.as_posix())
-                filesize = file_object.content_length
-                with tqdm(total=filesize, unit='B',
-                          unit_scale=True, desc=local_path.as_posix()) as t:
-                    file_object.download_file(Filename=str(local_path), Callback=_callback_hook(t))
-            except (NoCredentialsError, PartialCredentialsError) as ex:
-                raise ex  # Credentials need updating in Alyx
-            except ClientError as ex:
-                if ex.response.get('Error', {}).get('Code', None) == '404':
-                    _logger.error(f'File {source_path} not found on {bucket_name}')
-                    out_files[-1] = None
+            out_files.append(
+                aws.s3_download_file(source_path, local_path, s3=s3, bucket_name=bucket_name))
         return out_files
 
     def _dset2url(self, dset, update_cache=True):
