@@ -10,6 +10,8 @@ directories, and a separate parameter file for each url containing the client pa
 caches file also sets the default client for when no url is provided.
 """
 import re
+import shutil
+
 from iblutil.io import params as iopar
 from getpass import getpass
 from pathlib import Path
@@ -282,27 +284,6 @@ def get_params_dir() -> Path:
     return Path(iopar.getfile(_PAR_ID_STR))
 
 
-def get_rest_dir(client=None) -> Path:
-    """Return path to REST cache directory
-
-    Parameters
-    ----------
-    client : str
-        Location of rest cache for a given database URL.  If None, the root REST cache directory is
-        returned
-
-    Returns
-    -------
-    pathlib.Path
-        The REST cache directory path
-    """
-    rest_dir = get_params_dir() / '.rest'
-    if client:
-        scheme, loc, *_ = urlsplit(client)
-        rest_dir /= Path(loc.replace(':', '_'), scheme)
-    return rest_dir
-
-
 def check_cache_conflict(cache_dir):
     """Asserts that a given directory is not currently used as a cache directory.
     This function checks whether a given directory is used as a cache directory for an Alyx
@@ -345,4 +326,19 @@ def _patch_params(par):
         par = par.set('HTTP_DATA_SERVER', default().HTTP_DATA_SERVER)
         save(par, par.ALYX_URL)
 
+    # Move old REST data
+    rest_dir = get_params_dir() / '.rest'
+    scheme, loc, *_ = urlsplit(par.ALYX_URL)
+    rest_dir /= Path(loc.replace(':', '_'), scheme)
+    new_rest_dir = Path(par.CACHE_DIR, '.rest')
+
+    if rest_dir.exists() and any(x for x in rest_dir.glob('*') if x.is_file()):
+        if not new_rest_dir.exists():
+            shutil.move(str(rest_dir), str(new_rest_dir))
+            from iblutil.io.params import set_hidden
+            set_hidden(new_rest_dir, True)
+        shutil.rmtree(rest_dir.parent)
+        if not any(get_params_dir().joinpath('.rest').glob('*')):
+            get_params_dir().joinpath('.rest').rmdir()
+
     return par
